@@ -22,12 +22,12 @@ class NSLoader(BaseLoader):
             "x-moon-os-language": "en-US",
             "x-moon-app-language": "en-US",
             "authorization": "",
-            "x-moon-app-internal-version": "303",
-            "x-moon-app-display-version": "1.15.0",
+            "x-moon-app-internal-version": "305",
+            "x-moon-app-display-version": "1.15.1",
             "x-moon-os": "IOS",
             "accept-encoding": "gzip;q=1.0, compress;q=0.5",
             "accept-language": "en-US;q=1.0",
-            "user-agent": "moon_ios/1.15.0 (com.nintendo.znma; build:303; iOS 14.6) "
+            "user-agent": "moon_ios/1.15.1 (com.nintendo.znma; build:305; iOS 14.6) "
             "Alamofire/4.8.2",
             "x-moon-timezone": "America/Los_Angeles",
         }
@@ -75,7 +75,6 @@ class NSLoader(BaseLoader):
     def get_api_data(self):
         self._make_access_headers()
         month_list = self.make_month_list()
-        data_list = []
         for m in month_list:
             # no data for this month for ns
             if m.month == datetime.now().month:
@@ -91,11 +90,10 @@ class NSLoader(BaseLoader):
             if not r.ok:
                 print(f"Get ns calendar api failed {str(r.text)}")
             try:
-                data_list.extend(list(r.json()["dailySummaries"].values()))
+                yield from list(r.json()["dailySummaries"].values())
             except Exception:
                 # just pass for now
                 pass
-        return data_list
 
     def make_track_dict(self):
         data_list = self.get_api_data()
